@@ -52,6 +52,9 @@ class Ec2Instance(NetworkEntity, AwsClient):
             iam_profile_id: The ID of the IAM profile.
             http_tokens: The HTTP tokens setting - optional or required.
             availability_zone: The availability zone the EC2 is in, if configured.
+            instance_type: The Instance type (i.e. 'm5.8xlarge').
+            ebs_optimized: Indication whether the EC2 instance has EBS optimization enabled of not.
+            monitoring_enabled: Indication if the launched EC2 instance will have detailed monitoring enabled.
     """
     def __init__(self,
                  account: str,
@@ -61,11 +64,13 @@ class Ec2Instance(NetworkEntity, AwsClient):
                  network_interfaces_ids: List[str],
                  state: str,
                  image_id: str,
-                 iam_profile_arn: Optional[str],
+                 iam_profile_name: Optional[str],
                  http_tokens: str,
-                 iam_profile_id: Optional[str],
                  availability_zone: Optional[str],
-                 tags: dict):
+                 tags: dict,
+                 instance_type: str,
+                 ebs_optimized: bool,
+                 monitoring_enabled: bool):
         NetworkEntity.__init__(self, name or instance_id, account, region, AwsServiceName.AWS_EC2_INSTANCE,
                                AwsServiceAttributes(aws_service_type=AwsServiceType.EC2.value, region=region))
         AwsClient.__init__(self)
@@ -74,14 +79,16 @@ class Ec2Instance(NetworkEntity, AwsClient):
         self.network_interfaces_ids: List[str] = network_interfaces_ids
         self.state: str = state
         self.image_id: str = image_id
-        self.iam_profile_arn: Optional[str] = iam_profile_arn
+        self.iam_profile_name: Optional[str] = iam_profile_name
         self.http_tokens: str = http_tokens
-        self.iam_profile_id: Optional[str] = iam_profile_id
         self.availability_zone: Optional[str] = availability_zone
         self.image_data: Optional[Ec2Image] = None
         self.raw_data: Ec2RawData = Ec2RawData()
         if tags:
             self.tags.update(tags)
+        self.instance_type: str = instance_type
+        self.ebs_optimized: bool = ebs_optimized
+        self.monitoring_enabled: bool = monitoring_enabled
 
     def __str__(self):
         name_or_id_msg = 'Instance Name: {}'.format(
