@@ -1,10 +1,9 @@
 import os
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import List, Optional, Set
+from typing import Optional, Set, Dict
 
 import yaml
-
 from cloudrail.knowledge.context.cloud_provider import CloudProvider
 
 
@@ -58,6 +57,19 @@ class ResourceType(str, Enum):
     QUEUING = 'queuing'
     NOTIFICATION = 'notification'
     STREAMING = 'streaming'
+    SECURITY_SERVICES = 'security_services'
+
+
+class BenchmarkType(str, Enum):
+    PCI_DSS = "PCI DSS"
+    CIS = "CIS"
+
+
+@dataclass
+class RemediationSteps:
+    console: str
+    terraform: Optional[str] = None
+    cloudformation: Optional[str] = None
 
 
 @dataclass
@@ -66,15 +78,14 @@ class RuleMetadata:
     name: str
     description: str
     logic: str
-    categories: List[str]
     severity: RuleSeverity
-    remediation_steps_tf: str
-    remediation_steps_console: str
+    remediation_steps: RemediationSteps
     rule_type: RuleType
     security_layer: SecurityLayer
     resource_types: Set[ResourceType]
     cloud_provider: CloudProvider = field(default=CloudProvider.AMAZON_WEB_SERVICES)
     is_deleted: bool = False
+    compliance: Dict[BenchmarkType, Dict[str, str]] = field(default_factory=dict)
 
 
 def rule_matches_query(rule_id: str, rule_name: str, query: Optional[str]) -> bool:
@@ -84,7 +95,8 @@ def rule_matches_query(rule_id: str, rule_name: str, query: Optional[str]) -> bo
 
 
 def get_rule_metadata_content(provider: CloudProvider) -> dict:
-    provider_name = 'aws' if provider == CloudProvider.AMAZON_WEB_SERVICES else 'azure'
+    provider_name = provider.to_shorthand_string()
+
     current_path = os.path.dirname(os.path.abspath(__file__))
     rules_metadata_path = os.path.join(current_path, f'{provider_name}/{provider_name}_rules_metadata.yaml')
     with open(rules_metadata_path, 'r') as file:
